@@ -19,11 +19,11 @@ import (
 	"context"
 	"encoding/base64"
 	"encoding/json"
+	"fmt"
 	"io"
 	"os"
 	"path/filepath"
 	"testing"
-	"text/template"
 	"time"
 
 	"github.com/go-git/go-billy/v5"
@@ -43,10 +43,6 @@ import (
 	"github.com/sigstore/sigstore/pkg/signature"
 )
 
-var (
-	tmpl = template.Must(template.ParseFiles("testdata/test.json.provenance"))
-)
-
 func TestMain(m *testing.M) {
 	clock = clockwork.NewFakeClockAt(time.Date(1984, time.April, 4, 0, 0, 0, 0, time.UTC))
 	os.Exit(m.Run())
@@ -77,61 +73,61 @@ func TestAttestCommitRef(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	attestor := NewAttestor(repo, sv, fakeRekor, cfg)
+	attestor := NewAttestor(repo, sv, fakeRekor, cfg, DigestTypeCommit)
 
-	fc := []fileContent{
+	ad := []gitAttestData{
 		{
-			Name:    filepath.Join(sha.String(), "test.json"),
-			Content: readFile(t, "testdata/test.json"),
-		},
-		{
-			Name:    filepath.Join(sha.String(), "test.json.sig"),
-			Content: generateAttestation(t, sha),
+			sha:         sha,
+			predName:    "test.json",
+			predicate:   readFile(t, "testdata/test.json"),
+			attName:     "test.json.sig",
+			attestation: generateAttestation(t, "gitCommit", sha),
 		},
 	}
+
 	t.Run("base", func(t *testing.T) {
-		attest1, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest1, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		verifyContent(t, repo, attest1, fc)
+		verifyContent(t, repo, attest1, ad)
 	})
 
 	t.Run("noop", func(t *testing.T) {
 		// Write same attestation to the same commit - should be a no-op.
-		attest2, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest2, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		verifyContent(t, repo, attest2, fc)
+		verifyContent(t, repo, attest2, ad)
 	})
 
 	t.Run("new commit", func(t *testing.T) {
 		// Make a new commit, write new attestation.
 
 		sha, err = w.Commit("empty commit", &git.CommitOptions{
-			Author:    &object.Signature{},
-			Committer: &object.Signature{},
+			Author:            &object.Signature{},
+			Committer:         &object.Signature{},
+			AllowEmptyCommits: true,
 		})
 		if err != nil {
 			t.Fatal(err)
 		}
 
-		attest3, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest3, err := attestor.WriteAttestation(ctx, CommitRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		fc = append(fc,
-			fileContent{
-				Name:    filepath.Join(sha.String(), "test.json"),
-				Content: content,
-			},
-			fileContent{
-				Name:    filepath.Join(sha.String(), "test.json.sig"),
-				Content: generateAttestation(t, sha),
+		ad = append(ad,
+			gitAttestData{
+				sha:         sha,
+				predName:    "test.json",
+				predicate:   readFile(t, "testdata/test.json"),
+				attName:     "test.json.sig",
+				attestation: generateAttestation(t, "gitCommit", sha),
 			},
 		)
-		verifyContent(t, repo, attest3, fc)
+		verifyContent(t, repo, attest3, ad)
 	})
 }
 
@@ -157,82 +153,84 @@ func TestAttestTreeRef(t *testing.T) {
 
 	cfg, _ := gitsignconfig.Get()
 
-	attestor := NewAttestor(repo, sv, fakeRekor, cfg)
+	attestor := NewAttestor(repo, sv, fakeRekor, cfg, DigestTypeTree)
 
-	fc := []fileContent{
+	ad := []gitAttestData{
 		{
-			Name:    filepath.Join(sha.String(), "test.json"),
-			Content: readFile(t, "testdata/test.json"),
-		},
-		{
-			Name:    filepath.Join(sha.String(), "test.json.sig"),
-			Content: generateAttestation(t, sha),
+			sha:         sha,
+			predName:    "test.json",
+			predicate:   readFile(t, "testdata/test.json"),
+			attName:     "test.json.sig",
+			attestation: generateAttestation(t, "gitTree", sha),
 		},
 	}
 	t.Run("base", func(t *testing.T) {
-		attest1, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest1, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		verifyContent(t, repo, attest1, fc)
+		verifyContent(t, repo, attest1, ad)
 	})
 
 	t.Run("noop", func(t *testing.T) {
 		// Write same attestation to the same commit - should be a no-op.
-		attest2, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest2, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		verifyContent(t, repo, attest2, fc)
+		verifyContent(t, repo, attest2, ad)
 	})
 
 	t.Run("new commit same tree", func(t *testing.T) {
 		// Make a new commit, but since this will point to the same tree, attestation is a no-op.
 		sha, err = w.Commit("empty commit", &git.CommitOptions{
-			Author:    &object.Signature{},
-			Committer: &object.Signature{},
+			Author:            &object.Signature{},
+			Committer:         &object.Signature{},
+			AllowEmptyCommits: true,
 		})
 		if err != nil {
 			t.Fatal(err)
 		}
 		sha = resolveTree(t, repo, sha)
 
-		attest3, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest3, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
-		verifyContent(t, repo, attest3, fc)
+		verifyContent(t, repo, attest3, ad)
 	})
 
 	t.Run("new commit new tree", func(t *testing.T) {
 		// Make a new commit, write new attestation.
 		sha = resolveTree(t, repo, writeRepo(t, w, fs, "testdata/bar.txt"))
 
-		attest3, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom")
+		attest3, err := attestor.WriteAttestation(ctx, TreeRef, sha, NewNamedReader(bytes.NewBufferString(content), name), "custom-pred-type")
 		if err != nil {
 			t.Fatalf("WriteAttestation: %v", err)
 		}
 
-		fc = append(fc,
-			fileContent{
-				Name:    filepath.Join(sha.String(), "test.json"),
-				Content: content,
-			},
-			fileContent{
-				Name:    filepath.Join(sha.String(), "test.json.sig"),
-				Content: generateAttestation(t, sha),
+		ad = append(ad,
+			gitAttestData{
+				sha:         sha,
+				predName:    "test.json",
+				predicate:   readFile(t, "testdata/test.json"),
+				attName:     "test.json.sig",
+				attestation: generateAttestation(t, "gitTree", sha),
 			},
 		)
-		verifyContent(t, repo, attest3, fc)
+		verifyContent(t, repo, attest3, ad)
 	})
 }
 
-type fileContent struct {
-	Name    string
-	Content string
+type gitAttestData struct {
+	sha         plumbing.Hash
+	predName    string
+	predicate   string
+	attName     string
+	attestation string
 }
 
-func verifyContent(t *testing.T, repo *git.Repository, sha plumbing.Hash, want []fileContent) {
+func verifyContent(t *testing.T, repo *git.Repository, sha plumbing.Hash, want []gitAttestData) {
 	t.Helper()
 
 	commit, err := repo.CommitObject(sha)
@@ -240,32 +238,40 @@ func verifyContent(t *testing.T, repo *git.Repository, sha plumbing.Hash, want [
 		t.Fatal(err)
 	}
 
-	files, err := commit.Files()
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	got := []fileContent{}
-	if err := files.ForEach(func(c *object.File) error {
-		content, err := c.Contents()
+	for _, w := range want {
+		// We'll just check the raw predicate file that was written,
+		// that doesn't get marshaled so it should be untouched.
+		fname := fmt.Sprintf("%v/%v", w.sha, w.predName)
+		gotPredFile, err := commit.File(fname)
 		if err != nil {
-			return err
+			t.Fatal(err)
+		}
+		gotPred, err := gotPredFile.Contents()
+		if err != nil {
+			t.Fatal(err)
+		}
+		diff := cmp.Diff(w.predicate, gotPred)
+		if diff != "" {
+			t.Errorf("fname %v does not match: %v", fname, diff)
 		}
 
-		got = append(got, fileContent{
-			Name:    c.Name,
-			Content: content,
-		})
-
-		return nil
-	}); err != nil {
-		t.Fatal(err)
-	}
-
-	if diff := cmp.Diff(want, got, cmpopts.SortSlices(func(i, j fileContent) bool {
-		return i.Name < j.Name
-	})); diff != "" {
-		t.Error(diff)
+		// The attestation does get marshalled though, so we can't do
+		// a simple diff, instead we'll need to parse things...
+		fname = fmt.Sprintf("%v/%v", w.sha, w.attName)
+		gotE := readDsse(t, commit, fname)
+		wantE := parseDsse(t, w.attestation)
+		// Ignore payload because we're going to handle that special
+		diff = cmp.Diff(gotE, wantE, cmpopts.IgnoreFields(dsse.Envelope{}, "Payload"))
+		if diff != "" {
+			t.Errorf("fname %v does not match: %v", fname, diff)
+		}
+		// Now let's check the payload.
+		gotJ := parsePayload(t, gotE)
+		wantJ := parsePayload(t, wantE)
+		diff = cmp.Diff(gotJ, wantJ)
+		if diff != "" {
+			t.Errorf("fname payload %v does not match: %v", fname, diff)
+		}
 	}
 }
 
@@ -286,6 +292,40 @@ func fakeRekor(_ context.Context, _ *client.Rekor, _, _ []byte) (*models.LogEntr
 	}, nil
 }
 
+func parsePayload(t *testing.T, d *dsse.Envelope) interface{} {
+	p, err := base64.StdEncoding.DecodeString(d.Payload)
+	if err != nil {
+		t.Fatal(err)
+	}
+	var j interface{}
+	err = json.Unmarshal(p, &j)
+	if err != nil {
+		t.Fatal(err)
+	}
+	return j
+}
+
+func parseDsse(t *testing.T, content string) *dsse.Envelope {
+	var e dsse.Envelope
+	err := json.Unmarshal([]byte(content), &e)
+	if err != nil {
+		t.Fatal(err)
+	}
+	return &e
+}
+
+func readDsse(t *testing.T, commit *object.Commit, fname string) *dsse.Envelope {
+	f, err := commit.File(fname)
+	if err != nil {
+		t.Fatal(err)
+	}
+	c, err := f.Contents()
+	if err != nil {
+		t.Fatal(err)
+	}
+	return parseDsse(t, c)
+}
+
 func readFile(t *testing.T, path string) string {
 	t.Helper()
 
@@ -317,17 +357,17 @@ func writeRepo(t *testing.T, w *git.Worktree, fs billy.Filesystem, path string)
 	return sha
 }
 
-func generateAttestation(t *testing.T, h plumbing.Hash) string {
+func generateAttestation(t *testing.T, digestType string, h plumbing.Hash) string {
 	t.Helper()
 
-	b := new(bytes.Buffer)
-	if err := tmpl.Execute(b, h); err != nil {
-		t.Fatal(err)
-	}
+	statement := fmt.Sprintf(
+		`{"_type":"https://in-toto.io/Statement/v1","subject":[{"digest":{"%s":"%s"}}],"predicateType":"custom-pred-type","predicate":{"foo":"bar"}}`,
+		digestType,
+		h.String())
 
 	att := dsse.Envelope{
 		PayloadType: "application/vnd.in-toto+json",
-		Payload:     base64.StdEncoding.EncodeToString(bytes.TrimSpace(b.Bytes())),
+		Payload:     base64.StdEncoding.EncodeToString([]byte(statement)),
 		Signatures:  []dsse.Signature{{Sig: "dGFjb2NhdA=="}},
 	}
 
