@@ -99,7 +99,7 @@ func TestGet(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if diff := cmp.Diff(want, got); diff != "" {
+	if diff := cmp.Diff(want, got, cmp.AllowUnexported(Config{})); diff != "" {
 		t.Error(diff)
 	}
 }
